==> jc-1.4.0.tar.gz: java/io/ObjectStreamClass__242.h <==
// final class java.io.ObjectStreamClass$2

// class file dependencies
// @dep_class c5ccdc8f52c1ae81 java_io_ObjectStreamClass__242
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_io_ObjectStreamClass__242_H_
#define _JC_java_io_ObjectStreamClass__242_H_

// Forward structure declarations
struct _jc_java_io_ObjectStreamClass$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_reflect_Constructor$object;

// Typedefs
typedef struct _jc_java_io_ObjectStreamClass__242$sub_refs	_jc_java_io_ObjectStreamClass__242$sub_refs;
typedef struct _jc_java_io_ObjectStreamClass__242$sub_nonrefs	_jc_java_io_ObjectStreamClass__242$sub_nonrefs;
typedef struct _jc_java_io_ObjectStreamClass__242$refs	_jc_java_io_ObjectStreamClass__242$refs;
typedef struct _jc_java_io_ObjectStreamClass__242$nonrefs	_jc_java_io_ObjectStreamClass__242$nonrefs;
typedef struct _jc_java_io_ObjectStreamClass__242$object	_jc_java_io_ObjectStreamClass__242$object;

typedef const struct _jc_java_io_ObjectStreamClass__242$vmethods	_jc_java_io_ObjectStreamClass__242$vmethods;
typedef const struct _jc_java_io_ObjectStreamClass__242$vtable	_jc_java_io_ObjectStreamClass__242$vtable;
typedef const struct _jc_java_io_ObjectStreamClass__242$vtype	_jc_java_io_ObjectStreamClass__242$vtype;

// Constructors
extern void _jc_java_io_ObjectStreamClass__242$method$_init$251575177a862b84(_jc_env *, struct _jc_java_io_ObjectStreamClass__242$object *, struct _jc_java_io_ObjectStreamClass$object *, struct _jc_java_lang_reflect_Constructor$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_io_ObjectStreamClass__242$method$run$b190d7b16d5785b8(_jc_env *, struct _jc_java_io_ObjectStreamClass__242$object *);

// Virtual method descriptors
extern _jc_method _jc_java_io_ObjectStreamClass__242$method_info$run$b190d7b16d5785b8;

// Virtual methods structure
struct _jc_java_io_ObjectStreamClass__242$vmethods {
	struct _jc_java_lang_Object$object	*(*run$b190d7b16d5785b8)(_jc_env *, struct _jc_java_io_ObjectStreamClass__242$object *);
};

// Vtable
struct _jc_java_io_ObjectStreamClass__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_ObjectStreamClass__242$vmethods	java_io_ObjectStreamClass__242;
};

// Vtype
struct _jc_java_io_ObjectStreamClass__242$vtype {
	_jc_type			type;
	_jc_java_io_ObjectStreamClass__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_ObjectStreamClass__242$sub_refs {
	struct _jc_java_io_ObjectStreamClass$object	*this;
	struct _jc_java_lang_reflect_Constructor$object	*val__24c;
};

// Reference instance fields (object)
struct _jc_java_io_ObjectStreamClass__242$refs {
    _jc_java_io_ObjectStreamClass__242$sub_refs	java_io_ObjectStreamClass__242;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_ObjectStreamClass__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_ObjectStreamClass__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_ObjectStreamClass__242$sub_nonrefs	java_io_ObjectStreamClass__242;
};

// Object instance structure
struct _jc_java_io_ObjectStreamClass__242$object {
	_jc_java_io_ObjectStreamClass__242$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_ObjectStreamClass__242$vtype	*vtype;
	_jc_java_io_ObjectStreamClass__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_ObjectStreamClass__242$vtype _jc_java_io_ObjectStreamClass__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_ObjectStreamClass__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_ObjectStreamClass__242$class_object;

#endif	/* _JC_java_io_ObjectStreamClass__242_H_ */

==> jc-1.4.5.tar.gz: java/io/ObjectStreamClass__242.h <==
// final class java.io.ObjectStreamClass$2

// class file dependencies
// @dep_class c5ccdc8f52c1ae81 java_io_ObjectStreamClass__242
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_io_ObjectStreamClass__242_H_
#define _JC_java_io_ObjectStreamClass__242_H_

// Forward structure declarations
struct _jc_java_io_ObjectStreamClass$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_reflect_Constructor$object;

// Typedefs
typedef struct _jc_java_io_ObjectStreamClass__242$sub_refs	_jc_java_io_ObjectStreamClass__242$sub_refs;
typedef struct _jc_java_io_ObjectStreamClass__242$sub_nonrefs	_jc_java_io_ObjectStreamClass__242$sub_nonrefs;
typedef struct _jc_java_io_ObjectStreamClass__242$refs	_jc_java_io_ObjectStreamClass__242$refs;
typedef struct _jc_java_io_ObjectStreamClass__242$nonrefs	_jc_java_io_ObjectStreamClass__242$nonrefs;
typedef struct _jc_java_io_ObjectStreamClass__242$object	_jc_java_io_ObjectStreamClass__242$object;

typedef const struct _jc_java_io_ObjectStreamClass__242$vmethods	_jc_java_io_ObjectStreamClass__242$vmethods;
typedef const struct _jc_java_io_ObjectStreamClass__242$vtable	_jc_java_io_ObjectStreamClass__242$vtable;
typedef const struct _jc_java_io_ObjectStreamClass__242$vtype	_jc_java_io_ObjectStreamClass__242$vtype;

// Constructors
extern void _jc_java_io_ObjectStreamClass__242$method$_init$251575177a862b84(_jc_env *, struct _jc_java_io_ObjectStreamClass__242$object *, struct _jc_java_io_ObjectStreamClass$object *, struct _jc_java_lang_reflect_Constructor$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_io_ObjectStreamClass__242$method$run$b190d7b16d5785b8(_jc_env *, struct _jc_java_io_ObjectStreamClass__242$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_io_ObjectStreamClass__242$method_info$run$b190d7b16d5785b8;

// Virtual methods structure
struct _jc_java_io_ObjectStreamClass__242$vmethods {
	struct _jc_java_lang_Object$object	*(*run$b190d7b16d5785b8)(_jc_env *, struct _jc_java_io_ObjectStreamClass__242$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_io_ObjectStreamClass__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_ObjectStreamClass__242$vmethods	java_io_ObjectStreamClass__242;
};

// Vtype
struct _jc_java_io_ObjectStreamClass__242$vtype {
	_jc_type			type;
	_jc_java_io_ObjectStreamClass__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_ObjectStreamClass__242$sub_refs {
	struct _jc_java_io_ObjectStreamClass$object	*this;
	struct _jc_java_lang_reflect_Constructor$object	*val__24c;
};

// Reference instance fields (object)
struct _jc_java_io_ObjectStreamClass__242$refs {
    _jc_java_io_ObjectStreamClass__242$sub_refs	java_io_ObjectStreamClass__242;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_ObjectStreamClass__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_ObjectStreamClass__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_ObjectStreamClass__242$sub_nonrefs	java_io_ObjectStreamClass__242;
};

// Object instance structure
struct _jc_java_io_ObjectStreamClass__242$object {
	_jc_java_io_ObjectStreamClass__242$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_ObjectStreamClass__242$vtype	*vtype;
	_jc_java_io_ObjectStreamClass__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_ObjectStreamClass__242$vtype _jc_java_io_ObjectStreamClass__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_ObjectStreamClass__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_ObjectStreamClass__242$class_object;

#endif	/* _JC_java_io_ObjectStreamClass__242_H_ */
